@@ -41,7 +41,7 @@
 #include <glib/gi18n.h>
 
 #include "gedit-automatic-spell-checker.h"
-
+#include "gedit-spell-utils.h"
 
 struct _GeditAutomaticSpellChecker {
 	GeditDocument		*doc;
@@ -72,7 +72,7 @@ static void
 check_word (GeditAutomaticSpellChecker *spell, GtkTextIter *start, GtkTextIter *end) 
 {
 	gchar *word;
-	
+
 	word = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (spell->doc), start, end, FALSE);
 
 	/*
@@ -160,11 +160,12 @@ check_range (GeditAutomaticSpellChecker *spell,
 	{
 		gtk_text_iter_forward_word_end(&start);
 		gtk_text_iter_backward_word_start(&start);
-	}	
+	}
 
 	wstart = start;
 	
-	while (gtk_text_iter_compare (&wstart, &end) < 0) 
+	while (gedit_spell_utils_skip_no_spell_check (&wstart, &end) &&
+	       gtk_text_iter_compare (&wstart, &end) < 0) 
 	{
 		gboolean inword; 
 
@@ -671,12 +672,29 @@ tag_table_changed (GtkTextTagTable            *table,
 				   gtk_text_tag_table_get_size (table) - 1);
 }
 
+static void 
+tag_added_or_removed (GtkTextTagTable            *table,
+		      GtkTextTag                 *tag,
+		      GeditAutomaticSpellChecker *spell)
+{
+	tag_table_changed (table, spell);
+}
+
+static void 
+tag_changed (GtkTextTagTable            *table,
+	     GtkTextTag                 *tag,
+	     gboolean                    size_changed,
+	     GeditAutomaticSpellChecker *spell)
+{
+	tag_table_changed (table, spell);
+}
+
 GeditAutomaticSpellChecker *
 gedit_automatic_spell_checker_new (GeditDocument     *doc,
 				   GeditSpellChecker *checker)
 {
 	GeditAutomaticSpellChecker *spell;
-
+	GtkTextTagTable *tag_table;
 	GtkTextIter start, end;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
@@ -688,16 +706,17 @@ gedit_automatic_spell_checker_new (GeditDocument     *doc,
 	spell = g_new0 (GeditAutomaticSpellChecker, 1);
 
 	spell->doc = doc;
+	spell->spell_checker = g_object_ref (checker);
 
-	g_object_ref (checker);
-	spell->spell_checker = checker;
-	
 	if (automatic_spell_checker_id == 0)
+	{
 		automatic_spell_checker_id = 
-			g_quark_from_static_string ("GeditAutomaticSpellCheckerID");
+			g_quark_from_string ("GeditAutomaticSpellCheckerID");
+	}
 	if (suggestion_id == 0)
-		suggestion_id = 
-			g_quark_from_static_string ("GeditAutoSuggestionID");
+	{
+		suggestion_id = g_quark_from_string ("GeditAutoSuggestionID");
+	}
 
 	g_object_set_qdata_full (G_OBJECT (doc), 
 				 automatic_spell_checker_id, 
@@ -744,14 +763,22 @@ gedit_automatic_spell_checker_new (GeditDocument     *doc,
 				"underline", PANGO_UNDERLINE_ERROR,
 				NULL);
 
-	g_return_val_if_fail (GTK_TEXT_BUFFER (doc)->tag_table != NULL, NULL);
+	tag_table = gtk_text_buffer_get_tag_table (GTK_TEXT_BUFFER (doc));
 
 	gtk_text_tag_set_priority (spell->tag_highlight, 
-				   gtk_text_tag_table_get_size (GTK_TEXT_BUFFER (doc)->tag_table) - 1);
+				   gtk_text_tag_table_get_size (tag_table) - 1);
 
-	g_signal_connect (GTK_TEXT_BUFFER (doc)->tag_table,
-			  "changed",
-                          G_CALLBACK (tag_table_changed),
+	g_signal_connect (tag_table,
+			  "tag-added",
+			  G_CALLBACK (tag_added_or_removed),
+			  spell);
+	g_signal_connect (tag_table,
+			  "tag-removed",
+			  G_CALLBACK (tag_added_or_removed),
+			  spell);
+	g_signal_connect (tag_table,
+			  "tag-changed",
+			  G_CALLBACK (tag_changed),
 			  spell);
 
 	/* we create the mark here, but we don't use it until text is
@@ -762,44 +789,55 @@ gedit_automatic_spell_checker_new (GeditDocument     *doc,
 					"gedit-automatic-spell-checker-insert-start");
 
 	if (spell->mark_insert_start == NULL)
+	{
 		spell->mark_insert_start = 
 			gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (doc),
 						     "gedit-automatic-spell-checker-insert-start",
 						     &start, 
 						     TRUE);
+	}
 	else
+	{
 		gtk_text_buffer_move_mark (GTK_TEXT_BUFFER (doc),
 					   spell->mark_insert_start,
 					   &start);
+	}
 
 	spell->mark_insert_end = gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (doc),
 					"gedit-automatic-spell-checker-insert-end");
 
 	if (spell->mark_insert_end == NULL)
+	{
 		spell->mark_insert_end = 
 			gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (doc),
 						     "gedit-automatic-spell-checker-insert-end",
 						     &start, 
 						     TRUE);
+	}
 	else
+	{
 		gtk_text_buffer_move_mark (GTK_TEXT_BUFFER (doc),
 					   spell->mark_insert_end,
 					   &start);
-
+	}
 
 	spell->mark_click = gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (doc),
 					"gedit-automatic-spell-checker-click");
 
 	if (spell->mark_click == NULL)
+	{
 		spell->mark_click = 
 			gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (doc),
 						     "gedit-automatic-spell-checker-click",
 						     &start, 
 						     TRUE);
+	}
 	else
+	{
 		gtk_text_buffer_move_mark (GTK_TEXT_BUFFER (doc),
 					   spell->mark_click,
 					   &start);
+	}
 
 	spell->deferred_check = FALSE;
 
@@ -838,7 +876,7 @@ gedit_automatic_spell_checker_free_internal (GeditAutomaticSpellChecker *spell)
 	
 	g_return_if_fail (spell != NULL);
 
-	table = GTK_TEXT_BUFFER (spell->doc)->tag_table;
+	table = gtk_text_buffer_get_tag_table (GTK_TEXT_BUFFER (spell->doc));
 
 	if (table != NULL)
 	{
